@@ -11,6 +11,11 @@ import (
 	"k8s.io/apimachinery/pkg/util/intstr"
 )
 
+const (
+	BackendRedisDeploymentName = "backend-redis"
+	SystemRedisDeploymentName  = "system-redis"
+)
+
 type Redis struct {
 	Options *RedisOptions
 }
@@ -48,7 +53,8 @@ const (
 	backendRedisConfigVolumeName  = "redis-config"
 	backendRedisConfigMapKey      = "redis.conf"
 	backendRedisContainerName     = "backend-redis"
-	backendRedisContainerCommand  = "/opt/rh/rh-redis32/root/usr/bin/redis-server"
+	backendRedisContainerCommand  = "/opt/rh/rh-redis5/root/usr/bin/redis-server"
+	systemRedisContainerCommand   = "/opt/rh/rh-redis5/root/usr/bin/redis-server"
 )
 
 func (redis *Redis) buildDeploymentConfigSpec() appsv1.DeploymentConfigSpec {
@@ -439,7 +445,7 @@ func (redis *Redis) SystemDeploymentConfig() *appsv1.DeploymentConfig {
 			APIVersion: "apps.openshift.io/v1",
 		},
 		ObjectMeta: metav1.ObjectMeta{
-			Name:   "system-redis",
+			Name:   SystemRedisDeploymentName,
 			Labels: redis.Options.SystemRedisLabels,
 		},
 		Spec: appsv1.DeploymentConfigSpec{
@@ -465,7 +471,7 @@ func (redis *Redis) SystemDeploymentConfig() *appsv1.DeploymentConfig {
 				},
 			},
 			Replicas: 1,
-			Selector: map[string]string{"deploymentConfig": "system-redis"},
+			Selector: map[string]string{"deploymentConfig": SystemRedisDeploymentName},
 			Template: &v1.PodTemplateSpec{
 				ObjectMeta: metav1.ObjectMeta{
 					Labels: redis.Options.SystemRedisPodTemplateLabels,
@@ -495,7 +501,7 @@ func (redis *Redis) SystemDeploymentConfig() *appsv1.DeploymentConfig {
 						v1.Container{
 							Name:      "system-redis",
 							Image:     "system-redis:latest",
-							Command:   []string{"/opt/rh/rh-redis32/root/usr/bin/redis-server"},
+							Command:   []string{systemRedisContainerCommand},
 							Args:      []string{"/etc/redis.d/redis.conf", "--daemonize", "no"},
 							Resources: *redis.Options.SystemRedisContainerResourceRequirements,
 							VolumeMounts: []v1.VolumeMount{
