@@ -21,6 +21,7 @@ type SystemSMTPSecretOptions struct {
 	Password          *string `validate:"required"`
 	Port              *string `validate:"required"`
 	Username          *string `validate:"required"`
+	FromAddress       *string
 }
 
 type PVCFileStorageOptions struct {
@@ -34,6 +35,7 @@ type SystemOptions struct {
 	EventHooksURL                          string  `validate:"required"`
 	ApicastSystemMasterProxyConfigEndpoint string  `validate:"required"`
 	AdminEmail                             *string `validate:"required"`
+	UserSessionTTL                         *string `validate:"required"`
 
 	ImageTag string `validate:"required"`
 
@@ -91,6 +93,8 @@ type SystemOptions struct {
 
 	IncludeOracleOptionalSettings bool
 
+	BackendServiceEndpoint string `validate:"required"`
+
 	// Used for monitoring objects
 	// Those objects are namespaced. However, objects includes labels, rules and expressions
 	// that need namespace filtering because they are "global" once imported
@@ -173,6 +177,10 @@ func DefaultSystemAdminEmail() string {
 	return ""
 }
 
+func DefaultUserSessionTTL() string {
+	return ""
+}
+
 func DefaultSystemMasterApicastAccessToken() string {
 	return oprand.String(8)
 }
@@ -205,6 +213,10 @@ func DefaultSystemSMTPUsername() string {
 	return ""
 }
 
+func DefaultSystemSMTPFromAddress() string {
+	return ""
+}
+
 func DefaultAppMasterContainerResourceRequirements() *v1.ResourceRequirements {
 	return &v1.ResourceRequirements{
 		Limits: v1.ResourceList{
