@@ -5,9 +5,10 @@ import (
 	"reflect"
 	"testing"
 
+	appsv1alpha1 "github.com/3scale/3scale-operator/apis/apps/v1alpha1"
 	"github.com/3scale/3scale-operator/pkg/3scale/amp/component"
 	"github.com/3scale/3scale-operator/pkg/3scale/amp/product"
-	appsv1alpha1 "github.com/3scale/3scale-operator/pkg/apis/apps/v1alpha1"
+	"github.com/3scale/3scale-operator/pkg/helper"
 	"github.com/google/go-cmp/cmp"
 	"github.com/google/go-cmp/cmp/cmpopts"
 	v1 "k8s.io/api/core/v1"
@@ -60,9 +61,9 @@ func testBackendListenerPodLabels() map[string]string {
 		"threescale_component_element": "listener",
 		"com.redhat.component-name":    "backend-listener",
 		"com.redhat.component-type":    "application",
-		"com.redhat.component-version": "2.10",
+		"com.redhat.component-version": helper.ParseVersion(BackendImageURL()),
 		"com.redhat.product-name":      "3scale",
-		"com.redhat.product-version":   "2.10",
+		"com.redhat.product-version":   product.ThreescaleRelease,
 		"deploymentConfig":             "backend-listener",
 	}
 }
@@ -74,9 +75,9 @@ func testBackendWorkerPodLabels() map[string]string {
 		"threescale_component_element": "worker",
 		"com.redhat.component-name":    "backend-worker",
 		"com.redhat.component-type":    "application",
-		"com.redhat.component-version": "2.10",
+		"com.redhat.component-version": helper.ParseVersion(BackendImageURL()),
 		"com.redhat.product-name":      "3scale",
-		"com.redhat.product-version":   "2.10",
+		"com.redhat.product-version":   product.ThreescaleRelease,
 		"deploymentConfig":             "backend-worker",
 	}
 }
@@ -88,9 +89,9 @@ func testBackendCronPodLabels() map[string]string {
 		"threescale_component_element": "cron",
 		"com.redhat.component-name":    "backend-cron",
 		"com.redhat.component-type":    "application",
-		"com.redhat.component-version": "2.10",
+		"com.redhat.component-version": helper.ParseVersion(BackendImageURL()),
 		"com.redhat.product-name":      "3scale",
-		"com.redhat.product-version":   "2.10",
+		"com.redhat.product-version":   product.ThreescaleRelease,
 		"deploymentConfig":             "backend-cron",
 	}
 }
