@@ -1,8 +1,8 @@
 package operator
 
 import (
+	appsv1alpha1 "github.com/3scale/3scale-operator/apis/apps/v1alpha1"
 	"github.com/3scale/3scale-operator/pkg/3scale/amp/component"
-	appsv1alpha1 "github.com/3scale/3scale-operator/pkg/apis/apps/v1alpha1"
 	"github.com/3scale/3scale-operator/pkg/helper"
 
 	"sigs.k8s.io/controller-runtime/pkg/client"
@@ -199,7 +199,6 @@ func (h *HighAvailabilityOptionsProvider) setSystemRedisOptions() error {
 
 	return nil
 
-	return nil
 }
 
 func (h *HighAvailabilityOptionsProvider) setSystemDatabaseOptions() error {
