@@ -4,9 +4,10 @@ import (
 	"reflect"
 	"testing"
 
+	appsv1alpha1 "github.com/3scale/3scale-operator/apis/apps/v1alpha1"
 	"github.com/3scale/3scale-operator/pkg/3scale/amp/component"
 	"github.com/3scale/3scale-operator/pkg/3scale/amp/product"
-	appsv1alpha1 "github.com/3scale/3scale-operator/pkg/apis/apps/v1alpha1"
+	"github.com/3scale/3scale-operator/pkg/helper"
 	"github.com/google/go-cmp/cmp"
 	"github.com/google/go-cmp/cmp/cmpopts"
 	v1 "k8s.io/api/core/v1"
@@ -28,9 +29,9 @@ func testPodTemplateLabels() map[string]string {
 		"threescale_component_element": "memcache",
 		"com.redhat.component-name":    "system-memcache",
 		"com.redhat.component-type":    "application",
-		"com.redhat.component-version": "2.10",
+		"com.redhat.component-version": helper.ParseVersion(SystemMemcachedImageURL()),
 		"com.redhat.product-name":      "3scale",
-		"com.redhat.product-version":   "2.10",
+		"com.redhat.product-version":   product.ThreescaleRelease,
 		"deploymentConfig":             "system-memcache",
 	}
 }
