@@ -1,6 +1,8 @@
 package adapters
 
 import (
+	"fmt"
+
 	"github.com/3scale/3scale-operator/pkg/3scale/amp/component"
 	"github.com/3scale/3scale-operator/pkg/common"
 	templatev1 "github.com/openshift/api/template/v1"
@@ -63,6 +65,10 @@ func (s *System) Parameters() []templatev1.Parameter {
 			Name:     "ADMIN_EMAIL",
 			Required: false,
 		},
+		templatev1.Parameter{
+			Name:     "USER_SESSION_TTL",
+			Required: false,
+		},
 		templatev1.Parameter{
 			Name:        "ADMIN_ACCESS_TOKEN",
 			Description: "Admin Access Token with all scopes and write permissions for API access.",
@@ -206,6 +212,8 @@ func (s *System) options() (*component.SystemOptions, error) {
 	o.AdminUsername = "${ADMIN_USERNAME}"
 	adminEmail := "${ADMIN_EMAIL}"
 	o.AdminEmail = &adminEmail
+	userSessionTTL := "${USER_SESSION_TTL}"
+	o.UserSessionTTL = &userSessionTTL
 	o.AmpRelease = "${AMP_RELEASE}"
 	o.ImageTag = "${AMP_RELEASE}"
 	o.ApicastAccessToken = "${APICAST_ACCESS_TOKEN}"
@@ -264,6 +272,7 @@ func (s *System) options() (*component.SystemOptions, error) {
 	o.SphinxPodTemplateLabels = s.sphinxPodTemplateLabels()
 	o.MemcachedLabels = s.memcachedLabels()
 	o.SMTPLabels = s.smtpLabels()
+	o.BackendServiceEndpoint = s.backendServiceEndpoint()
 
 	// Currently, only used for monitoring resources. Thus, it does not apply to templates.
 	o.Namespace = "${NAMESPACE}"
@@ -344,3 +353,7 @@ func (s *System) smtpLabels() map[string]string {
 	labels["threescale_component_element"] = "smtp"
 	return labels
 }
+
+func (s *System) backendServiceEndpoint() string {
+	return fmt.Sprintf("%s%s", component.DefaultBackendServiceEndpoint(), "/internal/")
+}
